summaryrefslogtreecommitdiffstats
path: root/src/usr/diag/attn/ipl/attnsvc.H
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/diag/attn/ipl/attnsvc.H')
-rw-r--r--src/usr/diag/attn/ipl/attnsvc.H26
1 files changed, 21 insertions, 5 deletions
diff --git a/src/usr/diag/attn/ipl/attnsvc.H b/src/usr/diag/attn/ipl/attnsvc.H
index aa5a974f0..8e49fca1f 100644
--- a/src/usr/diag/attn/ipl/attnsvc.H
+++ b/src/usr/diag/attn/ipl/attnsvc.H
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2014,2015 */
+/* Contributors Listed Below - COPYRIGHT 2014,2018 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -130,22 +130,38 @@ class Service : public ServiceCommon
ConfigureMode i_mode);
/**
- * @brief intrTask infinite wait-for-interrupt loop
+ * @brief intrTask will start the intrTaskWorker
+ * and monitor if it crashes.
+ *
+ * @param[in] i_svc service object associated with task
+ */
+ static void* intrTask(void * i_svc);
+
+ /**
+ * @brief prdTask will start the prdTaskWorker
+ * and monitor if it crashes.
+ *
+ * @param[in] i_svc service object associated with task
+ */
+ static void* prdTask(void * i_svc);
+
+ /**
+ * @brief intrTaskWorker infinite wait-for-interrupt loop
*
* repeatedly call intrTaskWait and processIntrQMsg
*
* @param[in] i_svc service object associated with task
*/
- static void* intrTask(void * i_svc);
+ static void* intrTaskWorker(void * i_svc);
/**
* @brief prdTask infinite wait-for-attention loop
*
* repeatedly call prdTaskWait and processAttentions
*
* @param[in] i_svc service object associated with task
*/
- static void* prdTask(void * i_svc);
+ static void* prdTaskWorker(void * i_svc);
/**
* @brief startIntrTask start task helper function
OpenPOWER on IntegriCloud
@@ -130,22 +130,38 @@ class Service : public ServiceCommon
/**
- * @brief prdTask infinite wait-for-attention loop
+ * @brief prdTaskWorker infinite wait-for-attention loop
*
* repeatedly call prdTaskWait and processAttentions